"""
MCPOrchestrator Types
编排器相关的类型定义
"""

# 这里可以添加编排器相关的类型定义
# 目前保持简单，为未来扩展预留
